@@ -9,7 +9,7 @@
 #define QT_FEATURE_getentropy -1
 #define QT_FEATURE_glib 1
 #define QT_FEATURE_glibc -1
-#define QT_FEATURE_posix_libiconv -1
+#define QT_FEATURE_posix_libiconv 1
 #define QT_FEATURE_gnu_libiconv -1
 #define QT_FEATURE_icu 1
 #define QT_FEATURE_iconv -1
@@ -17,6 +17,7 @@
 #define QT_FEATURE_journald -1
 #define QT_FEATURE_linkat -1
 #define QT_FEATURE_lttng -1
+#define QT_FEATURE_mimetype_database 1
 #define QT_FEATURE_poll_ppoll -1
 #define QT_FEATURE_poll_pollts 1
 #define QT_FEATURE_poll_poll -1
