@@ -56,8 +56,7 @@
 #define QT_FEATURE_xcb_egl_plugin 1
 #define QT_FEATURE_xcb_glx_plugin 1
 #define QT_FEATURE_xcb_glx 1
-#define QT_FEATURE_xcb_native_painting 1
+#define QT_FEATURE_xcb_native_painting -1
 #define QT_FEATURE_xcb_sm 1
 #define QT_FEATURE_xcb_xinput 1
 #define QT_FEATURE_xkb 1
-#define QT_FEATURE_xrender 1
